@@ -34,7 +34,7 @@ logger = logging.getLogger('__name__')
 
 
 """
-obj:`Callbacks` encapsulate a set of functions to be applied at given
+`Callbacks` encapsulate a set of functions to be applied at given
 stages of the training procedure to customize the trainer behavior. 
 The relevant callbacks functions will then be called at the 
 various stages of the model training lifecycle, such as when:
@@ -85,7 +85,6 @@ class Callback(ABC):
 
 @dataclass
 class CallbackList(Callback):
-        
     """ Internal class that just calls the list of callbacks.
     The CallbackList serves two main purposes:
         1. It stores all the callbacks.
@@ -207,7 +206,7 @@ class TrainingStep(Callback):
     
     def on_train_begin(self):
         message = self.model.summary()
-        logger.info(message)
+        print(message)
         
     def on_train_batch_begin(self, step: int, batch: InputFeatures):
         self.train_step_output = self.train_step(batch)
@@ -218,7 +217,7 @@ class TrainingStep(Callback):
         
 @dataclass
 class History(Callback):
-    """ Callback that records the performance of the model 
+    """ Callback that record the performance of the model 
     during training. It stores all the evaluation metrics 
     such as loss and accuracy at each training and testing
     steps. This allows to track the progress of the model
@@ -237,11 +236,12 @@ class History(Callback):
         """ """
         self.loss_train_metric = self.loss_metric()
         self.loss_test_metric = self.loss_metric()
-        self.acc_train_metric = self.acc_metric()
-        self.acc_test_metric = self.acc_metric()
+        self.acc_train_metric = self.acc_metric
+        self.acc_test_metric = self.acc_metric
         
     def on_train_begin(self):
-        """ """
+        """ Initialize the logger with the performance metrics
+        that need to be historized """
         self.logs['loss'] = {}
         self.logs['acc'] = {}
         self.logs['val_loss'] = {}
@@ -249,14 +249,7 @@ class History(Callback):
     
     def on_epoch_begin(self, epoch: int):
         """ Resets all of the metric state variables """
-        
         self.epoch = epoch
-        '''
-        self.logs['loss'][epoch] = []
-        self.logs['acc'][epoch] = []
-        self.logs['val_loss'][epoch] = []
-        self.logs['val_acc'][epoch] = []
-        '''
         self.loss_train_metric.reset_states()
         self.loss_test_metric.reset_states()
         self.acc_train_metric.reset_states()
@@ -264,16 +257,20 @@ class History(Callback):
         
     def on_epoch_end(self, epoch: int):
         """ Display the performance metrics after each epoch """
+        message = f"\nEpoch - {epoch+1}  \n" \
+                  f"---------- \n" \
+                  f"Train - " \
+                  f"loss: {self.logs['loss'][epoch]:1.4f} - " \
+                  f"accuracy: {self.logs['acc'][epoch]:1.4f} \n" \
+                  f"Test - " \
+                  f"loss: {self.logs['val_loss'][epoch]:1.4f} - " \
+                  f"accuracy: {self.logs['val_acc'][epoch]:1.4f} \n"        
         
-        message = f"Training loss:       {self.logs['loss'][epoch]:1.3f}" \
-                  f"Training accuracy:   {self.logs['acc'][epoch]:1.3f}" \
-                  f"Validation loss:     {self.logs['val_loss'][epoch]:1.3f}" \
-                  f"Validation accuracy: {self.logs['val_acc'][epoch]:1.3f}"
-        
-        logger.info(message)     
+        logger.info(message)
 
     def on_train_batch_end(self, step: int, input_batch: InputFeatures):
-        """ Compute the performance metrics for each training batch """
+        """ Compute the performance metrics after each batch at 
+        training time """
         epoch = self.epoch
         output_batch = self.training_step.train_step_output
 
@@ -283,13 +280,14 @@ class History(Callback):
         
         self.loss_train_metric.update_state(loss)
         self.acc_train_metric.update_state(labels, logits)
-        
         self.logs['loss'][epoch] = self.loss_train_metric.result()
         self.logs['acc'][epoch] = self.acc_train_metric.result()
         
         
     def on_test_batch_end(self, step: int, input_batch: InputFeatures):
-        """ Compute the performance metrics for each testing batch """
+        """ Compute the performance metrics after each batch at 
+        testing time """
+        
         epoch = self.epoch
         output_batch = self.training_step.test_step_output
         
@@ -305,6 +303,7 @@ class History(Callback):
         
     @property
     def best_result(self) -> float:
+        """ Return the best performance metric among epochs """
         return min(self.logs['val_loss'].values())
     
 
@@ -322,7 +321,7 @@ class ModelCheckpoint(Callback):
     checkpoints_dir: str = 'checkpoints'
 
     def __post_init__(self):
-        """ Create the directory for saving checkpoints. """
+        """ Create the directory for saving checkpoints """
         if self.direction not in ['minimize', 'maximize']:
             raise ValueError
         if self.direction == 'maximize':
@@ -335,7 +334,7 @@ class ModelCheckpoint(Callback):
             os.makedirs(self.checkpoints_dir)
 
     def on_epoch_end(self, epoch: int):
-        """ Pass the obj:`ModelCheckpoint` callback after the obj:`History`. """
+        """ Save the model checkpoint if the performance improves """
         result = self.history.logs['val_loss'][epoch]
         diff = self.best_result - result
         is_better = diff > 0 if self.direction == 'minimize' else diff < 0
@@ -347,16 +346,14 @@ class ModelCheckpoint(Callback):
             self.model.save_pretrained(model_dir)
             self.best_result = result
             self.best_model_dir = model_dir
-            message = f'New model checkpoint saved'
-            logger.info(message)
 
 
 @dataclass
 class CSVLogger(Callback):
-    """ Callback that save the logs of the performance metrics
+    """ Callback that store the logs of the performance metrics
     into a csv file. """
     
-    name: str = 'CSVLogging'
+    name: str = 'CSVLogger'
     logs_dir: str = None
     level: int = 20
     msg_format: str = '%(asctime)s [%(levelname)-5s] %(message)s'
@@ -396,14 +393,15 @@ class EarlyStopping(Callback):
     direction: str = 'maximize'
 
     def __post_init__(self):
-        """ """
         if self.direction not in ['minimize', 'maximize']:
             raise ValueError
         if self.direction == 'maximize':
             self.best_result = 0
 
     def on_epoch_end(self, epoch: int):
-        """ """
+        """ Check if the model is improving after each epoch
+        and stop the training process if no improvement after
+        a certain amount of iteration."""
         result = self.history.logs['val_loss'][epoch]
         diff = self.best_result - result
         is_better = diff > self.min_delta if self.direction == 'minimize' \
@@ -419,11 +417,14 @@ class EarlyStopping(Callback):
 
 @dataclass
 class TimedStopping(Callback):
-    """ Callbacks that stop training the model when a specified
-    amount of time has passed.
+    """ Callbacks that stop training the model when a 
+    specified amount of time has passed.
+    
     Args:
-        time_limit: maximum amount of time in seconds before stopping.
-        stopped_epoch: the epoch number where the training loop stopped.
+        time_limit: maximum amount of time in seconds 
+             before stopping.
+        stopped_epoch: the epoch number where the training
+              stopped.
     """
 
     name: str = 'TimedStopping'
@@ -458,9 +459,8 @@ class TimedStopping(Callback):
 
 @dataclass
 class ProgbarLogger(Callback):
-    """ Callbacks to monitor the progress of a model's training, 
-    and display the progress bar and performance metrics in the
-    console. """ 
+    """ Callbacks that display a progress bar with performance metrics
+    to monitor the progress of a model's training in the console """ 
     
     name: str = 'ProgbarLogger'
     history: History = None
@@ -479,10 +479,8 @@ class ProgbarLogger(Callback):
         self.num_steps: int = int(self.num_samples/self.batch_size)
         self.update_interval = 1/self.update_per_second
         self.last_update_time = time.time()
-        self.overall_bar_format: str = "{l_bar}{bar} {n_fmt}/{total_fmt} " \
-                                       "ETA: {remaining}s, {rate_fmt}{postfix}"
-        self.epoch_bar_format: str = "Batch {n_fmt}/{total_fmt}{bar} " \
-                                     "ETA: {remaining}s - {desc}"
+        self.bar_format: str = "Batch {n_fmt}/{total_fmt}{bar} " \
+                               "ETA: {remaining}s - {desc}"
         self.metrics_format: str = "{name}: {value:0.4f}" 
         self.metrics_separator: str = " - "
         
@@ -502,7 +500,7 @@ class ProgbarLogger(Callback):
                 self.epoch_progress_tqdm=self.tqdm(
                     total=self.num_steps,
                     position=0,
-                    bar_format=self.epoch_bar_format,
+                    bar_format=self.bar_format,
                     leave=False,
                     dynamic_ncols=True,
                     unit="steps",
@@ -513,7 +511,7 @@ class ProgbarLogger(Callback):
                     desc="Testing progress",
                     total=self.num_steps,
                     position=0,
-                    bar_format=self.epoch_bar_format,
+                    bar_format=self.bar_format,
                     leave=False,
                     dynamic_ncols=True,
                     unit="steps",
@@ -530,10 +528,10 @@ class ProgbarLogger(Callback):
             if self.show_epoch_progress and time_diff >= self.update_interval:
                 
                 self.epoch_progress_tqdm.desc = \
-                     f"loss: {self.train_logs['loss']:04F} - " \
-                     f"accuracy: {self.train_logs['acc']:04F} - " \
-                     f"val_loss: {self.test_logs['loss']:04F} - " \
-                     f"val_accuracy: {self.test_logs['acc']:04F}"
+                     f"loss: {self.train_logs['loss']:.4f} - " \
+                     f"accuracy: {self.train_logs['acc']:.4f} - " \
+                     f"val_loss: {self.test_logs['loss']:.4f} - " \
+                     f"val_accuracy: {self.test_logs['acc']:.4f}"
 
                 self.epoch_progress_tqdm.update(self.steps_to_update)
                 self.steps_to_update = 0
@@ -574,15 +572,15 @@ class ProgbarLogger(Callback):
         self.epoch_progress_tqdm.close()
 
     def on_train_batch_end(self, step: int, input_batch: InputFeatures):
-        train_logs = defaultdict(float)
-        train_logs["loss"] = self.history.logs['loss'][self.epoch]
-        train_logs["acc"] = self.history.logs['acc'][self.epoch]
-        self.train_logs = train_logs
+        logs = defaultdict(float)
+        logs["loss"] = self.history.logs['loss'][self.epoch]
+        logs["acc"] = self.history.logs['acc'][self.epoch]
+        self.train_logs = logs
         self._update_progbar()
         
     def on_test_batch_end(self, step: int, input_batch: InputFeatures):
-        test_logs = defaultdict(float)
-        test_logs["loss"] = self.history.logs['val_loss'][self.epoch]
-        test_logs["acc"] = self.history.logs['val_acc'][self.epoch]
-        self.test_logs = test_logs 
+        logs = defaultdict(float)
+        logs["loss"] = self.history.logs['val_loss'][self.epoch]
+        logs["acc"] = self.history.logs['val_acc'][self.epoch]
+        self.test_logs = logs 
         self._update_progbar()
