@@ -26,8 +26,7 @@ as input batch by the model. """
 
 
 @dataclass
-class DataProcessorForLanguageModeling:
-    
+class LanguageModelingDataProcessor:
     """ 
     Data processor for Masked Language Modeling:
     80% MASK, 10% random, 10% original.
@@ -63,6 +62,8 @@ class DataProcessorForLanguageModeling:
             truncation=True,
             max_length=512,
             is_split_into_words=False,
+            return_attention_mask=True,
+            return_token_type_ids=True,
             return_tensors='tf',
         )
         
@@ -136,10 +137,9 @@ class DataProcessorForLanguageModeling:
 
 
 @dataclass
-class DataProcessorForSequenceClassification:
-    
+class SingleLabelDataProcessor:
     """
-    Data Processor for Sequence Classification.
+    Data Processor for single-label sequence classification.
     Inputs are dynamically padded to the maximum 
     length of a batch if they are not all of the 
     same length.
@@ -154,7 +154,7 @@ class DataProcessorForSequenceClassification:
         The configuration of the model.
     """
     
-    name: str = 'SequenceClassificationProcessor'
+    name: str = 'SingleLabelClassificationProcessor'
     tokenizer: PreTrainedTokenizer = None
     config: PretrainedConfig = None
     seq_max_len: int = 512
@@ -172,6 +172,8 @@ class DataProcessorForSequenceClassification:
             truncation=True,
             max_length=self.seq_max_len,
             is_split_into_words=False,
+            return_attention_mask=True,
+            return_token_type_ids=True,
             return_tensors='tf',
         )
         
@@ -188,4 +190,63 @@ class DataProcessorForSequenceClassification:
         )
         
         return input_features
+
+
+@dataclass(frozen=True)
+class MultiLabelDataProcessor:
+    """
+    Data Processor for multi-label sequence classification.
+    Inputs are dynamically padded to the maximum length of a
+    batch if they are not all of the same length.
+    
+    Args
+    ----------
+
+    tokenizer (transformers.PreTrainedTokenizer):
+        The tokenizer used for encoding the data.
+
+    config (transformers.PreTrainedCOnfig):
+        The configuration of the model.
+    """
+    
+    name: str = 'MultiLabelClassificationProcessor'
+    tokenizer: PreTrainedTokenizer = None
+    config: PretrainedConfig = None
+    seq_max_len: int = 512
+    
+    def __call__(self, 
+                 examples: List[InputExample],
+                ) -> InputFeatures:
+        
+        texts = [example.text for example in examples]
+        
+        inputs = self.tokenizer(
+            texts,
+            add_special_tokens=True,
+            padding=True,
+            truncation=True,
+            max_length=self.seq_max_len,
+            is_split_into_words=False,
+            return_attention_mask=True,
+            return_token_type_ids=True,
+            return_tensors='tf',
+        )
+        
+        labels = [example.label for example in examples]
+        ragged_labels = tf.ragged.constant(labels)	
+        onehot_labels = tf.one_hot(
+            ragged_labels,
+            depth=self.config.num_labels,
+        )
+        
+        inputs['label'] = tf.reduce_max(onehot_labels, axis=1)
+        
+        input_features = InputFeatures(
+            input_ids=inputs['input_ids'],
+            attention_mask=inputs['attention_mask'],
+            token_type_ids=inputs['token_type_ids'],
+            label=inputs['label'],
+        )
+        
+        return input_features
     
\ No newline at end of file
