@@ -43,7 +43,7 @@ class Trainer():
             
             for epoch in range(self.num_epochs):
                 callbacks.on_epoch_begin(epoch)
-
+                
                 for step, batch in enumerate(self.train_stream):
                     callbacks.on_train_batch_begin(step, batch)
                     callbacks.on_train_batch_end(step, batch)
@@ -62,7 +62,6 @@ class Trainer():
             callbacks.on_train_end()
              
         except:
-            message = 'Unexpected error during the training process.'
-            logger.error(message)
-            sys.exit()
+            message = 'The training process has been stopped.'
+            logger.info(message)
             
\ No newline at end of file
